import Vue from 'vue'
import Router from 'vue-router'


Vue.use(Router)
/**
 * Note: 路由配置项
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    keepAlive: true              // 如果设置为true，则会被 <keep-alive> 缓存 (默认 false)
    title: 'title'               // 设置该路由在页面顶部的Title
    index: '1'                   // 设置该路由页面切换是否左右滑动及权重，如不设页面不滑动  PS：功能暂时未启用
    hidden: true                 // 如果设置为true，显示底部菜单，如不设或者false，不显示
  }
 */
export const constantRoutes = [
  {
    path: '/',
    redirect: '/index'
  },
  {
    path: '/index',
    name: 'index',
    meta: {
      title: '主页',
      keepAlive: true
    },
    component: (resolve) => require(['@/views/index'], resolve)
  },
  {
    path: '/login',
    name: 'login',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/login'], resolve)
  },
  {
    path: '/register',
    name: 'register',
    meta: {
      title: '注册页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register'], resolve)
  },
  {
    path: '/document',
    name: 'document',
    meta: {
      title: '文档',
    },
    component: (resolve) => require(['@/views/document'], resolve)
  },
  {
    path: '/workbench',
    name: 'workbench',
    meta: {
      title: '工作台'
    },
    component: (resolve) => require(['@/views/workbench'], resolve)
  },
  {
    path: '/addressBook',
    name: 'addressBook',
    meta: {
      title: '通讯录'
    },
    component: (resolve) => require(['@/views/addressBook'], resolve)
  },
  {
    path: '/mynsgk',
    name: 'mynsgk',
    meta: {
      title: '我的'
    },
    component: (resolve) => require(['@/views/mynsgk'], resolve)
  },
  {
    path: '/authenticRight',
    name: 'authenticRight',
    meta: {
      title: '确权颁证调查统计表',
    },
    component: (resolve) => require(['@/views/authenticRight/index'], resolve)
  },
  {
    path: '/biddingHall',
    name: 'biddingHall',
    meta: {
      title: '竞价大厅',
      hidden: true,
    },
    component: (resolve) => require(['@/views/biddingHall'], resolve)
  },
  {
    path: '/project',
    name: 'project',
    meta: {
      title: '挂牌项目'
    },
    component: (resolve) => require(['@/views/project'], resolve)
  },
  {
    path: '/project/projectDetail',
    name: 'projectDetail',
    meta: {
      title: '挂牌项目',
      hidden: true
    },
    component: (resolve) => require(['@/views/project/projectDetail'], resolve)
  },
  {
    path: '/news/index',
    name: 'news',
    meta: {
      title: '新闻资讯',
      hidden: true,
    },
    component: (resolve) => require(['@/views/news/index'], resolve)
  },
  {
    path: '/news/newDetail',
    name: 'newDetail',
    meta: {
      title: '新闻详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/news/newDetail'], resolve)
  },
  {
    path: '/notice/index',
    name: 'notice',
    meta: {
      title: '项目公告',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/index'], resolve)
  },
  {
    path: '/supply/index',
    name: 'supply',
    meta: {
      title: '个人供求',
      hidden: true,
    },
    component: (resolve) => require(['@/views/supply/index'], resolve)
  },
  {
    path: '/interaction/index',
    name: 'interaction',
    meta: {
      title: '互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/interaction/index'], resolve)
  },
  {
    path: '/register/index',
    name: 'registerAgreement',
    meta: {
      title: '注册须知',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/index'], resolve)
  },
  {
    path: '/register/registerType',
    name: 'registerType',
    meta: {
      title: '注册类型',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/registerType'], resolve)
  },
  {
    path: '/register/userRegister',
    name: 'userRegister',
    meta: {
      title: '个人用户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/userRegister'], resolve)
  },
  {
    path: '/register/companyRegister',
    name: 'companyRegister',
    meta: {
      title: '单位用户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/companyRegister'], resolve)
  },
  {
    path: '/user',
    name: 'user',
    meta: {
      title: '个人中心',
    },
    component: (resolve) => require(['@/views/user/index'], resolve)
  },
  {
    path: '/accountSetting',
    name: 'accountSetting',
    meta: {
      title: '账户设置',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/index'], resolve)
  },
  {
    path: '/companyInformation',
    name: 'companyInformation',
    meta: {
      title: '资料修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/userInformation/companyInformation'], resolve)
  },
  {
    path: '/userInformation',
    name: 'userInformation',
    meta: {
      title: '资料修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/userInformation/userInformation'], resolve)
  },
  {
    path: '/bankInformation',
    name: 'bankInformation',
    meta: {
      title: '银行账户修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/bankInformation/index'], resolve)
  },
  {
    path: '/passWordInformation',
    name: 'passWordInformation',
    meta: {
      title: '密码修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/passWordInformation/index'], resolve)
  },
  {
    path: '/phoneInformation',
    name: 'phoneInformation',
    meta: {
      title: '手机号修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/phoneInformation/index'], resolve)
  },
  {
    path: '/bidding',
    name: 'bidding',
    meta: {
      title: '我的竞价',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/bidding/index'], resolve)
  },
  {
    path: '/userInteraction',
    name: 'userInteraction',
    meta: {
      title: '我的咨询',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/interaction/index'], resolve)
  },
  {
    path: '/userSupply',
    name: 'userSupply',
    meta: {
      title: '我的供求',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/supply/index'], resolve)
  },
  {
    path: '/policy',
    name: 'policy',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/policy/index'], resolve)
  },
  {
    path: '/project/signUp',
    name: 'signUp',
    meta: {
      title: '报名',
      hidden: true
    },
    component: (resolve) => require(['@/views/project/signUp'], resolve)
  },
  {
    path: '/noticeDetail',
    name: 'noticeDetail',
    meta: {
      title: '公告详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/noticeDetail'], resolve)
  },
  {
    path: '/attestationDetail',
    name: 'attestationDetail',
    meta: {
      title: '鉴证详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/attestationDetail'], resolve)
  },
  {
    path: '/policyDetail',
    name: 'policyDetail',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/policy/policyDetail'], resolve)
  },
  {
    path: '/interactionAdd',
    name: 'interactionAdd',
    meta: {
      title: '添加互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/interaction/interactionAdd'], resolve)
  },
  {
    path: '/supplyAdd',
    name: 'supplyAdd',
    meta: {
      title: '添加互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/supply/supplyAdd'], resolve)
  },
  //两清三化宅基地
  {
    path: '/homestead/index',
    name: 'homesteadIndex',
    meta: {
      title: '两清三化宅基地',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homestead/index'], resolve)
  },
  {
    path: '/homestead/login',
    name: 'homesteadLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homestead/login'], resolve)
  },
  //两清三化宅基地
  {
    path: '/authenticRight/index',
    name: 'authenticRightIndex',
    meta: {
      title: '两清三化宅基地',
      hidden: true,
    },
    component: (resolve) => require(['@/views/authenticRight/index'], resolve)
  },
  {
    path: '/authenticRight/login',
    name: 'authenticRightLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/authenticRight/login'], resolve)
  },
  {
    path: '/yinnongLogin',
    name: 'yinnongLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnongLogin'], resolve)
  },
  {
    path: '/yinnongIndex',
    name: 'yinnongIndex',
    meta: {
      title: '银农',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnongIndex'], resolve)
  },
  {
    path: '/yinnong/publicity',
    name: 'yinnongPublicity',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/publicity'], resolve)
  },
  {
    path: '/yinnong/workbench',
    name: 'yinnongWorkbench',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/workbench'], resolve)
  },
  {
    path: '/yinnong/home',
    name: 'yinnongHome',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/home'], resolve)
  },
  {
    path: '/yinnong/my',
    name: 'yinnongMy',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/my'], resolve)
  },
  {
    path: '/onlineHomeLogin',
    name: 'onlineHomeLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHomeLogin'], resolve)
  },
  {
    path: '/onlineHomeIndex',
    name: 'onlineHomeIndex',
    meta: {
      title: '网上家园',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHomeIndex'], resolve)
  },
  {
    path: '/onlineHome/publicity',
    name: 'onlineHomePublicity',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/publicity'], resolve)
  },
  {
    path: '/onlineHome/workbench',
    name: 'onlineHomeWorkbench',
    meta: {
      title: '工作台',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/workbench'], resolve)
  },
  {
    path: '/onlineHome/home',
    name: 'onlineHomeHome',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/home'], resolve)
  },
  {
    path: '/onlineHome/my',
    name: 'onlineHomeMy',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/my'], resolve)
  },
  {
    path: '/onlineHome/threeAffairs',
    name: 'onlineHomeThreeAffairs',
    meta: {
      title: '三务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/threeAffairs'], resolve)
  },
  {
    path: '/onlineHome/threeAffairsDetail',
    name: 'threeAffairsDetail',
    meta: {
      title: '三务公开详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/threeAffairsDetail'], resolve)
  },
  {
    path: '/onlineHome/villageAffairsDetail',
    name: 'villageAffairsDetail',
    meta: {
      title: '村规民约详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/villageAffairsDetail'], resolve)
  },
  {
    path: '/onlineHome/homePoll',
    name: 'onlineHomeHomePoll',
    meta: {
      title: '投票',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homePoll'], resolve)
  },
  {
    path: '/onlineHome/incomeDetail',
    name: 'onlineHomeIncomeDetail',
    meta: {
      title: '收入明细公开表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/incomeDetail'], resolve)
  },
  {
    path: '/onlineHome/expenditureDetail',
    name: 'onlineHomeExpenditureDetail',
    meta: {
      title: '支出明细公开表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/expenditureDetail'], resolve)
  },
  {
    path: '/onlineHome/inAndOutDetail',
    name: 'onlineHomeInAndOutDetail',
    meta: {
      title: '收支明细公开表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/inAndOutDetail'], resolve)
  },
  {
    path: '/onlineHome/mailList',
    name: 'onlineHomeMailList',
    meta: {
      title: '通讯录',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/mailList'], resolve)
  }
  ,
  {
    path: '/onlineHome/password',
    name: 'onlineHomePassword',
    meta: {
      title: '密码修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/password'], resolve)
  },
  {
    path: '/onlineHome/livePay',
    name: 'onlineHomeLivePay',
    meta: {
      title: '生活缴费',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/livePay'], resolve)
  },
  {
    path: '/onlineHome/personalPicture',
    name: 'onlineHomePersonalPicture',
    meta: {
      title: '画像',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/personalPicture'], resolve)
  },
  {
    path: '/onlineHome/done',
    name: 'onlineHomeDone',
    meta: {
      title: '我的已办',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/done'], resolve)
  },
  {
    path: '/onlineHome/advice',
    name: 'onlineHomeAdvice',
    meta: {
      title: '投诉建议',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/advice'], resolve)
  },
  {
    path: '/applicationForm',
    name: 'applicationForm',
    meta: {
      title: '农村宅基地申请表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/applicationForm'], resolve)
  },
  {
    path: '/applicationList',
    name: 'applicationList',
    meta: {
      title: '宅基地申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/applicationList'], resolve)
  },
  {
    path: '/certificateList',
    name: 'certificateList',
    meta: {
      title: '证书查看',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/certificate/certificateList'], resolve)
  },
  {
    path: '/certificateSee',
    name: 'certificateSee',
    meta: {
      title: '证书查看',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/certificate/certificateSee'], resolve)
  },
  {
    path: '/informationList',
    name: 'informationList',
    meta: {
      title: '公示信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/publicityInformation/informationList'], resolve)
  },
  {
    path: '/informationDetail',
    name: 'informationDetail',
    meta: {
      title: '公示信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/publicityInformation/informationDetail'], resolve)
  },
  {
    path: '/circulationList',
    name: 'circulationList',
    meta: {
      title: '使用权流转',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationList'], resolve)
  },
  {
    path: '/circulationAdd',
    name: 'circulationAdd',
    meta: {
      title: '添加宅基地使用权流转',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationAdd'], resolve)
  }
  ,
  {
    path: '/onlineHome/zcfg',
    name: 'zcfg',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/zcfg'], resolve)
  },
  {
    path: '/onlineHome/hnzc',
    name: 'hnzc',
    meta: {
      title: '惠农政策',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/hnzc'], resolve)
  },
  {
    path: '/onlineHome/gzdt',
    name: 'gzdt',
    meta: {
      title: '工作动态',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/gzdt'], resolve)
  },
  {
    path: '/onlineHome/zdjs',
    name: 'zdjs',
    meta: {
      title: '制度建设',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/zdjs'], resolve)
  },
  {
    path: '/onlineHome/homePollDetail',
    name: 'homePollDetail',
    meta: {
      title: '投票详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homePollDetail'], resolve)
  },
  {
    path: '/flowChart',
    name: 'flowChart',
    meta: {
      title: '宅基地申请流程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/flowChart/index'], resolve)
  },
  {
    path: '/applicationAdd',
    name: 'applicationAdd',
    meta: {
      title: '宅基地申请流程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/applicationAdd'], resolve)
  },
  {
    path: '/paidExit',
    name: 'paidExit',
    meta: {
      title: '有偿退出',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitList'], resolve)
  },
  {
    path: '/paidExitAdd',
    name: 'paidExitAdd',
    meta: {
      title: '有偿退出',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitAdd'], resolve)
  },
  {
    path: '/mortgage',
    name: 'mortgage',
    meta: {
      title: '使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageList'], resolve)
  },
  {
    path: '/mortgageAdd',
    name: 'mortgageAdd',
    meta: {
      title: '使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageAdd'], resolve)
  },
  {
    path: '/utilization',
    name: 'utilization',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationList'], resolve)
  },
  {
    path: '/utilizationDetail',
    name: 'utilizationDetail',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationDetail'], resolve)
  },
  {
    path: '/utilizationAdd',
    name: 'utilizationAdd',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationAdd'], resolve)
  },
  {
    path: '/utilizationModify',
    name: 'utilizationModify',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationModify'], resolve)
  },
  {
    path: '/homesteadUtilize',
    name: 'homesteadUtilize',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilize'], resolve)
  },
  {
    path: '/homesteadUtilizeAdd',
    name: 'homesteadUtilizeAdd',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilizeAdd'], resolve)
  },
  {
    path: '/homesteadUtilizeDetail',
    name: 'homesteadUtilizeDetail',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilizeDetail'], resolve)
  },
  {
    path: '/homesteadUtilizeModify',
    name: 'homesteadUtilizeModify',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilizeModify'], resolve)
  },
  {
    path: '/circulationDetail',
    name: 'circulationDetail',
    meta: {
      title: '查看宅基地使用权流转',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationDetail'], resolve)
  },
  {
    path: '/circulationModify',
    name: 'circulationModify',
    meta: {
      title: '修改宅基地使用权流转',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationModify'], resolve)
  },
  {
    path: '/mortgageDetail',
    name: 'mortgageDetail',
    meta: {
      title: '查看使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageDetail'], resolve)
  },
  {
    path: '/mortgageModify',
    name: 'mortgageModify',
    meta: {
      title: '修改使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageModify'], resolve)
  },
  {
    path: '/paidExitDetail',
    name: 'paidExitDetail',
    meta: {
      title: '有偿退出详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitDetail'], resolve)
  },
  {
    path: '/paidExitModify',
    name: 'paidExitModify',
    meta: {
      title: '有偿退出修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitModify'], resolve)
  },
  {
    path: '/paidUtilizeList',
    name: 'paidUtilizeList',
    meta: {
      title: '有偿利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidUtilize/paidUtilizeList'], resolve)
  },
  {
    path: '/paidUtilizeModify',
    name: 'paidUtilizeModify',
    meta: {
      title: '修改有偿利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidUtilize/paidUtilizeModify'], resolve)
  },
  {
    path: '/paidUtilizeDteail',
    name: 'paidUtilizeDteail',
    meta: {
      title: '查看有偿利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidUtilize/paidUtilizeDteail'], resolve)
  },
  {
    path: '/paidUtilizeAdd',
    name: 'paidUtilizeAdd',
    meta: {
      title: '添加有偿利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidUtilize/paidUtilizeAdd'], resolve)
  },
  {
    path: '/task',
    name: 'task',
    meta: {
      title: '发布任务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskList'], resolve)
  },
  {
    path: '/taskRelease',
    name: 'taskRelease',
    meta: {
      title: '发布任务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskRelease'], resolve)
  },
  {
    path: '/taskLssueAdd',
    name: 'taskLssueAdd',
    meta: {
      title: '添加任务下发',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskLssueAdd'], resolve)
  },
  {
    path: '/taskLssueModify',
    name: 'taskLssueModify',
    meta: {
      title: '修改任务下发',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskLssueModify'], resolve)
  },
  {
    path: '/taskCloseCaseAdd',
    name: 'taskCloseCaseAdd',
    meta: {
      title: '结案',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskCloseCaseAdd'], resolve)
  },
  {
    path: '/taskCloseCaseList',
    name: 'taskCloseCaseList',
    meta: {
      title: '上报明细',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskCloseCaseList'], resolve)
  },
  {
    path: '/taskReportingList',
    name: 'taskReportingList',
    meta: {
      title: '任务上报',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskReportingList'], resolve)
  },
  {
    path: '/taskReportingDetail',
    name: 'taskReportingDetail',
    meta: {
      title: '结案',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskReportingDetail'], resolve)
  },
  {
    path: '/taskDetailedList',
    name: 'taskDetailedList',
    meta: {
      title: '上报明细',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskDetailedList'], resolve)
  },
  {
    path: '/taskReportingAdd',
    name: 'taskReportingAdd',
    meta: {
      title: '任务上报',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskReportingAdd'], resolve)
  },
  {
    path: '/supervisionList',
    name: 'supervisionList',
    meta: {
      title: '违法监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionList'], resolve)
  },
  {
    path: '/supervisionAdd',
    name: 'supervisionAdd',
    meta: {
      title: '添加宅基地监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionAdd'], resolve)
  },
  {
    path: '/supervisionModify',
    name: 'supervisionModify',
    meta: {
      title: '修改宅基地监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionModify'], resolve)
  },
  {
    path: '/supervisionCloseCase',
    name: 'supervisionCloseCase',
    meta: {
      title: '修改宅基地监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionCloseCase'], resolve)
  },
  {
    path: '/approvalForm',
    name: 'approvalForm',
    meta: {
      title: '宅基地审批',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApproval/approvalForm'], resolve)
  },
  // {
  //   path: '/onlineHome/approvalList',
  //   name: 'approvalList',
  //   meta: {
  //     title: '银行卡转账列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList2',
  //   name: 'approvalList2',
  //   meta: {
  //     title: '信用卡还款列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList2'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList3',
  //   name: 'approvalList3',
  //   meta: {
  //     title: '虚拟挂账列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList3'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList4',
  //   name: 'approvalList4',
  //   meta: {
  //     title: '代管转账列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList4'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList5',
  //   name: 'approvalList5',
  //   meta: {
  //     title: '母子转账列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList5'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList10',
  //   name: 'approvalList10',
  //   meta: {
  //     title: '现金提现列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList10'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList11',
  //   name: 'approvalList11',
  //   meta: {
  //     title: '备付金支出列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList11'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalList12',
  //   name: 'approvalList12',
  //   meta: {
  //     title: '汇票支出列表',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalList12'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail',
  //   name: 'approvalDetail',
  //   meta: {
  //     title: '银农银行卡转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail2',
  //   name: 'approvalDetail2',
  //   meta: {
  //     title: '银农信用卡还款申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail2'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail3',
  //   name: 'approvalDetail3',
  //   meta: {
  //     title: '银农虚拟挂账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail3'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail4',
  //   name: 'approvalDetail4',
  //   meta: {
  //     title: '银农代管转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail4'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail5',
  //   name: 'approvalDetail5',
  //   meta: {
  //     title: '银农母子转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail5'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail10',
  //   name: 'approvalDetail10',
  //   meta: {
  //     title: '银农现金提现申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail10'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail11',
  //   name: 'approvalDetail11',
  //   meta: {
  //     title: '银农备付金支出申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail11'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalDetail12',
  //   name: 'approvalDetail12',
  //   meta: {
  //     title: '银农汇票支出申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalDetail12'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd',
  //   name: 'approvalAdd',
  //   meta: {
  //     title: '添加银行卡转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd2',
  //   name: 'approvalAdd2',
  //   meta: {
  //     title: '添加信用卡还款申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd2'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd3',
  //   name: 'approvalAdd3',
  //   meta: {
  //     title: '添加虚拟挂账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd3'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd4',
  //   name: 'approvalAdd4',
  //   meta: {
  //     title: '添加代管转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd4'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd5',
  //   name: 'approvalAdd5',
  //   meta: {
  //     title: '添加母子转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd5'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd10',
  //   name: 'approvalAdd10',
  //   meta: {
  //     title: '添加现金提现申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd10'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd11',
  //   name: 'approvalAdd11',
  //   meta: {
  //     title: '添加备付金支出申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd11'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalAdd12',
  //   name: 'approvalAdd12',
  //   meta: {
  //     title: '添加汇票支出申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalAdd12'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalApproval',
  //   name: 'approvalApproval',
  //   meta: {
  //     title: '付款审批',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalApproval'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalApproval10',
  //   name: 'approvalApproval10',
  //   meta: {
  //     title: '付款审批',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalApproval10'], resolve)
  // },{
  //   path: '/onlineHome/approvalApproval11',
  //   name: 'approvalApproval11',
  //   meta: {
  //     title: '付款审批',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalApproval11'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalApproval12',
  //   name: 'approvalApproval12',
  //   meta: {
  //     title: '付款审批',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalApproval12'], resolve)
  // },
  //
  // {
  //   path: '/onlineHome/approvalModify',
  //   name: 'approvalModify',
  //   meta: {
  //     title: '修改银行卡转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify2',
  //   name: 'approvalModify2',
  //   meta: {
  //     title: '修改信用卡还款申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify2'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify3',
  //   name: 'approvalModify3',
  //   meta: {
  //     title: '修改虚拟挂账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify3'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify4',
  //   name: 'approvalModify4',
  //   meta: {
  //     title: '修改代管转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify4'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify5',
  //   name: 'approvalModify5',
  //   meta: {
  //     title: '修改母子转账申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify5'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify10',
  //   name: 'approvalModify10',
  //   meta: {
  //     title: '修改现金提现申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify10'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify11',
  //   name: 'approvalModify11',
  //   meta: {
  //     title: '修改备付金支出申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify11'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalModify12',
  //   name: 'approvalModify12',
  //   meta: {
  //     title: '修改汇票支出申请',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalModify12'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalProcess',
  //   name: 'approvalProcess',
  //   meta: {
  //     title: '付款申请流程',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalProcess'], resolve)
  // },
  // {
  //   path: '/onlineHome/approvalProcess2',
  //   name: 'approvalProcess2',
  //   meta: {
  //     title: '付款申请流程',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentApproval/approvalProcess2'], resolve)
  // },
  // {
  //   path: '/onlineHome/collectionList',
  //   name: 'collectionList',
  //   meta: {
  //     title: '银农支付收款账户',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/collectionAccount/collectionList'], resolve)
  // },
  // {
  //   path: '/onlineHome/collectionAdd',
  //   name: 'collectionAdd',
  //   meta: {
  //     title: '添加支付收款账户',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/collectionAccount/collectionAdd'], resolve)
  // },
  // {
  //   path: '/onlineHome/collectionModify',
  //   name: 'collectionModify',
  //   meta: {
  //     title: '修改支付收款账户',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/collectionAccount/collectionModify'], resolve)
  // },
  // {
  //   path: '/onlineHome/collectionDetail',
  //   name: 'collectionDetail',
  //   meta: {
  //     title: '查看支付收款账户',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/collectionAccount/collectionDetail'], resolve)
  // },
  // {
  //   path: '/onlineHome/paymentAccountList',
  //   name: 'paymentAccountList',
  //   meta: {
  //     title: '查看支付收款账户',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentAccount/paymentAccountList'], resolve)
  // },
  // {
  //   path: '/onlineHome/paymentAccountAdd',
  //   name: 'paymentAccountAdd',
  //   meta: {
  //     title: '添加出纳账户设置',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentAccount/paymentAccountAdd'], resolve)
  // },
  // {
  //   path: '/onlineHome/paymentAccountModify',
  //   name: 'paymentAccountModify',
  //   meta: {
  //     title: '修改出纳账户设置',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentAccount/paymentAccountModify'], resolve)
  // },
  // {
  //   path: '/onlineHome/paymentAccountDetail',
  //   name: 'paymentAccountDetail',
  //   meta: {
  //     title: '付款账户详情',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/bankAgriculture/paymentAccount/paymentAccountDetail'], resolve)
  // },
  // {
  //   path: '/onlineHome/villagePortrait',
  //   name: 'villagePortrait',
  //   meta: {
  //     title: '村画像',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/villagePortrait'], resolve)
  // },
  // {
  //   path: '/onlineHome/farmerPortrait',
  //   name: 'farmerPortrait',
  //   meta: {
  //     title: '村民信息',
  //     hidden: true,
  //   },
  //   component: (resolve) => require(['@/views/onlineHome/farmerPortrait'], resolve)
  // },
  {
    path: '/yinnong/threeAffairs',
    name: 'yinnongThreeAffairs',
    meta: {
      title: '三务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/threeAffairs'], resolve)
  },
  {
    path: '/yinnong/threeAffairsDetail',
    name: 'yinnongThreeAffairsDetail',
    meta: {
      title: '三务公开详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/threeAffairsDetail'], resolve)
  },
  {
    path: '/yinnong/villageAffairsDetail',
    name: 'yinnongVillageAffairsDetail',
    meta: {
      title: '村规民约详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/villageAffairsDetail'], resolve)
  },
  {
    path: '/yinnong/zcfg',
    name: 'yinnongzcfg',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/zcfg'], resolve)
  },
  {
    path: '/yinnong/hnzc',
    name: 'yinnonghnzc',
    meta: {
      title: '惠农政策',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/hnzc'], resolve)
  },
  {
    path: '/yinnong/gzdt',
    name: 'yinnonggzdt',
    meta: {
      title: '工作动态',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/gzdt'], resolve)
  },
  {
    path: '/yinnong/zdjs',
    name: 'yinnongzdjs',
    meta: {
      title: '制度建设',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/zdjs'], resolve)
  },
  {
    path: '/yinnong/homePoll',
    name: 'yinnongHomePoll',
    meta: {
      title: '投票',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/homePoll'], resolve)
  },
  {
    path: '/yinnong/homePollDetail',
    name: 'yinnongPollDetail',
    meta: {
      title: '投票详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/homePollDetail'], resolve)
  },
  {
    path: '/yinnong/mailList',
    name: 'yinnongMailList',
    meta: {
      title: '通讯录',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/mailList'], resolve)
  }
  ,
  {
    path: '/yinnong/password',
    name: 'yinnongPassword',
    meta: {
      title: '密码修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/password'], resolve)
  },
  {
    path: '/yinnong/livePay',
    name: 'yinnongLivePay',
    meta: {
      title: '生活缴费',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/livePay'], resolve)
  },
  {
    path: '/yinnong/personalPicture',
    name: 'yinnongPersonalPicture',
    meta: {
      title: '画像',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/personalPicture'], resolve)
  },
  {
    path: '/yinnong/done',
    name: 'yinnongDone',
    meta: {
      title: '我的已办',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/done'], resolve)
  },
  {
    path: '/yinnong/advice',
    name: 'yinnongAdvice',
    meta: {
      title: '投诉建议',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/advice'], resolve)
  },
  {
    path: '/yinnong/approvalList',
    name: 'approvalList',
    meta: {
      title: '银行卡转账列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList'], resolve)
  },
  {
    path: '/yinnong/approvalList2',
    name: 'approvalList2',
    meta: {
      title: '信用卡还款列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList2'], resolve)
  },
  {
    path: '/yinnong/approvalList3',
    name: 'approvalList3',
    meta: {
      title: '虚拟挂账列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList3'], resolve)
  },
  {
    path: '/yinnong/approvalList4',
    name: 'approvalList4',
    meta: {
      title: '代管转账列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList4'], resolve)
  },
  {
    path: '/yinnong/approvalList5',
    name: 'approvalList5',
    meta: {
      title: '母子转账列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList5'], resolve)
  },
  {
    path: '/yinnong/approvalList10',
    name: 'approvalList10',
    meta: {
      title: '现金提现列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList10'], resolve)
  },
  {
    path: '/yinnong/approvalList11',
    name: 'approvalList11',
    meta: {
      title: '备付金支出列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList11'], resolve)
  },
  {
    path: '/yinnong/approvalList12',
    name: 'approvalList12',
    meta: {
      title: '汇票支出列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalList12'], resolve)
  },
  {
    path: '/yinnong/approvalDetail',
    name: 'approvalDetail',
    meta: {
      title: '银农银行卡转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail'], resolve)
  },
  {
    path: '/yinnong/approvalDetail2',
    name: 'approvalDetail2',
    meta: {
      title: '银农信用卡还款申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail2'], resolve)
  },
  {
    path: '/yinnong/approvalDetail3',
    name: 'approvalDetail3',
    meta: {
      title: '银农虚拟挂账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail3'], resolve)
  },
  {
    path: '/yinnong/approvalDetail4',
    name: 'approvalDetail4',
    meta: {
      title: '银农代管转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail4'], resolve)
  },
  {
    path: '/yinnong/approvalDetail5',
    name: 'approvalDetail5',
    meta: {
      title: '银农母子转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail5'], resolve)
  },
  {
    path: '/yinnong/approvalDetail10',
    name: 'approvalDetail10',
    meta: {
      title: '银农现金提现申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail10'], resolve)
  },
  {
    path: '/yinnong/approvalDetail11',
    name: 'approvalDetail11',
    meta: {
      title: '银农备付金支出申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail11'], resolve)
  },
  {
    path: '/yinnong/approvalDetail12',
    name: 'approvalDetail12',
    meta: {
      title: '银农汇票支出申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalDetail12'], resolve)
  },
  {
    path: '/yinnong/approvalAdd',
    name: 'approvalAdd',
    meta: {
      title: '添加银行卡转账申请',
      hidden: true,
      keepAlive: true
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd'], resolve)
  },
  {
    path: '/yinnong/approvalAdd2',
    name: 'approvalAdd2',
    meta: {
      title: '添加信用卡还款申请',
      hidden: true,
      keepAlive: true
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd2'], resolve)
  },
  {
    path: '/yinnong/approvalAdd3',
    name: 'approvalAdd3',
    meta: {
      title: '添加虚拟挂账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd3'], resolve)
  },
  {
    path: '/yinnong/approvalAdd4',
    name: 'approvalAdd4',
    meta: {
      title: '添加代管转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd4'], resolve)
  },
  {
    path: '/yinnong/approvalAdd5',
    name: 'approvalAdd5',
    meta: {
      title: '添加母子转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd5'], resolve)
  },
  {
    path: '/yinnong/approvalAdd10',
    name: 'approvalAdd10',
    meta: {
      title: '添加现金提现申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd10'], resolve)
  },
  {
    path: '/yinnong/approvalAdd11',
    name: 'approvalAdd11',
    meta: {
      title: '添加备付金支出申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd11'], resolve)
  },
  {
    path: '/yinnong/approvalAdd12',
    name: 'approvalAdd12',
    meta: {
      title: '添加汇票支出申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalAdd12'], resolve)
  },
  {
    path: '/yinnong/approval/collectionAdd',
    name: 'approvalCollectionAdd',
    meta: {
      title: '添加收款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/collectionAdd'], resolve)
  },
  {
    path: '/yinnong/approval/collectionAdd2',
    name: 'approvalCollectionAdd2',
    meta: {
      title: '添加收款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/collectionAdd2'], resolve)
  },
  {
    path: '/yinnong/approval/collectionApprovalAdd',
    name: 'collectionApprovalAdd',
    meta: {
      title: '添加收款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/collectionApprovalAdd'], resolve)
  },
  {
    path: '/yinnong/approvalApproval',
    name: 'approvalApproval',
    meta: {
      title: '付款审批',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalApproval'], resolve)
  },
  {
    path: '/yinnong/approvalApproval10',
    name: 'approvalApproval10',
    meta: {
      title: '付款审批',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalApproval10'], resolve)
  }, {
    path: '/yinnong/approvalApproval11',
    name: 'approvalApproval11',
    meta: {
      title: '付款审批',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalApproval11'], resolve)
  },
  {
    path: '/yinnong/approvalApproval12',
    name: 'approvalApproval12',
    meta: {
      title: '付款审批',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalApproval12'], resolve)
  },

  {
    path: '/yinnong/approvalModify',
    name: 'approvalModify',
    meta: {
      title: '修改银行卡转账申请',
      hidden: true,
      keepAlive: true
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify'], resolve)
  },
  {
    path: '/yinnong/approvalModify2',
    name: 'approvalModify2',
    meta: {
      title: '修改信用卡还款申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify2'], resolve)
  },
  {
    path: '/yinnong/approvalModify3',
    name: 'approvalModify3',
    meta: {
      title: '修改虚拟挂账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify3'], resolve)
  },
  {
    path: '/yinnong/approvalModify4',
    name: 'approvalModify4',
    meta: {
      title: '修改代管转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify4'], resolve)
  },
  {
    path: '/yinnong/approvalModify5',
    name: 'approvalModify5',
    meta: {
      title: '修改母子转账申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify5'], resolve)
  },
  {
    path: '/yinnong/approvalModify10',
    name: 'approvalModify10',
    meta: {
      title: '修改现金提现申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify10'], resolve)
  },
  {
    path: '/yinnong/approvalModify11',
    name: 'approvalModify11',
    meta: {
      title: '修改备付金支出申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify11'], resolve)
  },
  {
    path: '/yinnong/approvalModify12',
    name: 'approvalModify12',
    meta: {
      title: '修改汇票支出申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalModify12'], resolve)
  },
  {
    path: '/yinnong/approvalProcess',
    name: 'approvalProcess',
    meta: {
      title: '付款申请流程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalProcess'], resolve)
  },
  {
    path: '/yinnong/approvalProcess2',
    name: 'approvalProcess2',
    meta: {
      title: '付款申请流程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentApproval/approvalProcess2'], resolve)
  },
  {
    path: '/yinnong/collectionList',
    name: 'collectionList',
    meta: {
      title: '银农收款账户列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/collectionAccount/collectionList'], resolve)
  },
  {
    path: '/yinnong/collectionAdd',
    name: 'collectionAdd',
    meta: {
      title: '添加收款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/collectionAccount/collectionAdd'], resolve)
  },
  {
    path: '/yinnong/collectionModify',
    name: 'collectionModify',
    meta: {
      title: '修改收款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/collectionAccount/collectionModify'], resolve)
  },
  {
    path: '/yinnong/collectionDetail',
    name: 'collectionDetail',
    meta: {
      title: '查看收款账户详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/collectionAccount/collectionDetail'], resolve)
  },
  {
    path: '/yinnong/paymentAccountList',
    name: 'paymentAccountList',
    meta: {
      title: '查看付款账户列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentAccount/paymentAccountList'], resolve)
  },
  {
    path: '/yinnong/paymentAccountAdd',
    name: 'paymentAccountAdd',
    meta: {
      title: '添加付款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentAccount/paymentAccountAdd'], resolve)
  },
  {
    path: '/yinnong/paymentAccountModify',
    name: 'paymentAccountModify',
    meta: {
      title: '修改付款账户信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentAccount/paymentAccountModify'], resolve)
  },
  {
    path: '/yinnong/paymentAccountDetail',
    name: 'paymentAccountDetail',
    meta: {
      title: '查看付款账户详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/paymentAccount/paymentAccountDetail'], resolve)
  },
  {
    path: '/yinnong/villagePortrait',
    name: 'yinnongvillagePortrait',
    meta: {
      title: '村画像',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/villagePortrait'], resolve)
  },
  {
    path: '/yinnong/farmerPortrait',
    name: 'yinnongfarmerPortrait',
    meta: {
      title: '村民信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/farmerPortrait'], resolve)
  },
  {
    path: '/yinnong/bankOfDepositList',
    name: 'yinnongBankOfDepositList',
    meta: {
      title: '开户行',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/bankOfDeposit/bankOfDepositList'], resolve)
  },
  {
    path: '/yinnong/bankOfDepositAdd',
    name: 'yinnongBankOfDepositAdd',
    meta: {
      title: '添加开户行',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/bankOfDeposit/bankOfDepositAdd'], resolve)
  },
  {
    path: '/yinnong/bankOfDepositModify',
    name: 'yinnongBankOfDepositModify',
    meta: {
      title: '修改开户行',
      hidden: true,
    },
    component: (resolve) => require(['@/views/yinnong/bankAgriculture/bankOfDeposit/bankOfDepositModify'], resolve)
  },
  {
    path: '/lawEnforcement',
    name: 'lawEnforcement',
    meta: {
      title: '农业综合行政执法公众平台',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/index'], resolve)
  },
  {
    path: '/lawEnforcement/caseList',
    name: 'caseList',
    meta: {
      title: '案件',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/case/caseList'], resolve)
  },
  {
    path: '/lawEnforcement/productsList',
    name: 'caseList',
    meta: {
      title: '农用品库',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/products/productsList'], resolve)
  },
  {
    path: '/lawEnforcement/user',
    name: 'user',
    meta: {
      title: '个人中心',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/user/index'], resolve)
  },
  {
    path: '/lawEnforcement/programme',
    name: 'programme',
    meta: {
      title: '方案管理',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/programme/programmeList'], resolve)
  },
  {
    path: '/lawEnforcement/programmeDetail',
    name: 'programmeDetail',
    meta: {
      title: '查看方案信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/programme/programmeDetail'], resolve)
  },
  {
    path: '/lawEnforcement/programmeModify',
    name: 'programmeModify',
    meta: {
      title: '修改方案信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/programme/programmeModify'], resolve)
  },
  {
    path: '/lawEnforcement/programmeApproval',
    name: 'programmeApproval',
    meta: {
      title: '审批历史',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/programme/programmeApproval'], resolve)
  },
  {
    path: '/lawEnforcement/complaint',
    name: 'complaint',
    meta: {
      title: '投诉回复',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/complaint/complaintList'], resolve)
  },
  {
    path: '/lawEnforcement/reply',
    name: 'reply',
    meta: {
      title: '投诉回复',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/complaint/reply'], resolve)
  },
  {
    path: '/lawEnforcement/changePassword',
    name: 'changePassword',
    meta: {
      title: '修改密码',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/changePassword/index'], resolve)
  },
  {
    path: '/lawEnforcement/feedback',
    name: 'feedback',
    meta: {
      title: '帮助反馈',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/feedback/index'], resolve)
  },
  {
    path: '/lawEnforcement/feedbackForm',
    name: 'feedbackForm',
    meta: {
      title: '我要反馈',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/feedback/feedbackForm'], resolve)
  },
  {
    path: '/lawEnforcement/agreement',
    name: 'agreement',
    meta: {
      title: '产品协议',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/agreement/index'], resolve)
  },
  {
    path: '/lawEnforcement/work',
    name: 'work',
    meta: {
      title: '工作动态',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/workDynamics/workList'], resolve)
  },
  {
    path: '/lawEnforcement/workDetail',
    name: 'workDetail',
    meta: {
      title: '工作动态',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/workDynamics/workDetail'], resolve)
  },
  {
    path: '/lawEnforcement/caseDetail',
    name: 'caseDetail',
    meta: {
      title: '案件详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/case/caseDetail'], resolve)
  },
  {
    path: '/lawEnforcement/login',
    name: 'lawEnforcementLogin',
    meta: {
      title: '登录',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/login'], resolve)
  },
  {
    path: '/lawEnforcement/userRegister',
    name: 'lawEnforcementUser',
    meta: {
      title: '个体工商户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/register/userRegister'], resolve)
  },
  {
    path: '/lawEnforcement/companyRegister',
    name: 'lawEnforcementCompanyRegister',
    meta: {
      title: '企业注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/register/companyRegister'], resolve)
  },
  {
    path: '/lawEnforcement/userInformation',
    name: 'lawUserInformation',
    meta: {
      title: '修改信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/user/userInformation'], resolve)
  },
  {
    path: '/lawEnforcement/companyInformation',
    name: 'lawCompanyInformation',
    meta: {
      title: '修改信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/user/companyInformation'], resolve)
  },
  {
    path: '/lawEnforcement/indexComplaint',
    name: 'indexComplaint',
    meta: {
      title: '投诉建议',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/complaint/indexComplaint'], resolve)
  },
  {
    path: '/lawEnforcement/userCaseDetail',
    name: 'userCaseDetail',
    meta: {
      title: '案件审批',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/user/caseDetail'], resolve)
  },
  {
    path: '/lawEnforcement/userCaseList',
    name: 'userCaseList',
    meta: {
      title: '案件审批列表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/user/caseList'], resolve)
  },
  {
    path: '/lawEnforcement/schemeDetail',
    name: 'schemeDetail',
    meta: {
      title: '方案详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/scheme/schemeDetail'], resolve)
  },
  {
    path: '/lawEnforcement/waitingProcessing',
    name: 'waitingProcessing',
    meta: {
      title: '待办事项',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/user/waitingProcessing'], resolve)
  },
  {
    path: '/lawEnforcement/complaintAdd',
    name: 'complaintAdd',
    meta: {
      title: '发布投诉',
      hidden: true,
    },
    component: (resolve) => require(['@/views/lawEnforcement/complaint/complaintAdd'], resolve)
  },
  {
    path: '/homesteadLogin',
    name: 'homesteadLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homesteadLogin'], resolve)
  },
  {
    path: '/homesteadSurvey/index',
    name: 'homesteadIndex',
    meta: {
      title: '宅基地调查',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homesteadSurvey/index'], resolve)
  },
  {
    path: '/homesteadSurvey/list',
    name: 'homesteadList',
    meta: {
      title: '宅基地调查',
      hidden: true
    },
    component: (resolve) => require(['@/views/homesteadSurvey/list'], resolve)
  },
  {
    path: '/homesteadSurvey/add',
    name: 'homesteadAdd',
    meta: {
      title: '宅基地调查',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homesteadSurvey/add'], resolve)
  },
  {
    path: '/homesteadSurvey/settle',
    name: 'homesteadSettle',
    meta: {
      title: '宅基地调查',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homesteadSurvey/settle'], resolve)
  },
  {
    path: '/onlineHome/licensePermitEdit',
    name: 'licensePermitEdit',
    meta: {
      title: '修改许可证',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/certificate/licensePermitEdit'], resolve)
  },
  {
    path: '/onlineHome/licenseRatificationEdit',
    name: 'licenseRatificationEdit',
    meta: {
      title: '修改批准书',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/certificate/licenseRatificationEdit'], resolve)
  },
  {
    path: '/proposerLite',
    name: 'proposerLite',
    meta: {
      title: '农村宅基地申请(简)',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/proposerLite'], resolve)
  },
  {
    path: '/sunVillage/login',
    name: 'sunVillageLogin',
    meta: {
      title: '登录',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/login'], resolve)
  },
  {
    path: '/sunVillage/index',
    name: 'sunVillage',
    meta: {
      title: '阳光村务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/index'], resolve)
  },
  {
    path: '/sunVillage/latestReport',
    name: 'latestReport',
    meta: {
      title: '最新报道',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/latestReport/index'], resolve)
  },
  {
    path: '/sunVillage/latestReport/details',
    name: 'latestReportDetails',
    meta: {
      title: '最新报道',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/latestReport/details'], resolve)
  },
  {
    path: '/sunVillage/importantItems',
    name: 'importantItems',
    meta: {
      title: '重大事项',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/importantItems/index'], resolve)
  },
  {
    path: '/sunVillage/importantItems/details',
    name: 'importantItemsDetails',
    meta: {
      title: '重大事项', //重大事项-详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/importantItems/details'], resolve)
  },
  {
    path: '/sunVillage/public',
    name: 'sunVillagePublic',
    meta: {
      title: '三务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/public/index'], resolve)
  },
  {
    path: '/sunVillage/public/details',
    name: 'sunVillagePublicDetails',
    meta: {
      title: '三务公开', //三务公开-详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/public/details'], resolve)
  },
  {
    path: '/sunVillage/financial',
    name: 'sunVillageFinancial',
    meta: {
      title: '惠民金融',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/financial/index'], resolve)
  },
  {
    path: '/sunVillage/financial/details',
    name: 'sunVillageFinancialDetails',
    meta: {
      title: '惠民金融', //惠民金融-详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/financial/details'], resolve)
  },
  {
    path: '/sunVillage/financial/products',
    name: 'sunVillageFinancialProducts',
    meta: {
      title: '惠民金融',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/financial/products'], resolve)
  },
  {
    path: '/sunVillage/financial/loan',
    name: 'sunVillageFinancialLoan',
    meta: {
      title: '惠民金融',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/financial/loan'], resolve)
  },
  {
    path: '/sunVillage/injoint',
    name: 'sunVillageInjoint',
    meta: {
      title: '三资公开', //财务公开
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/index'], resolve)
  },
  {
    path: '/sunVillage/injoint/details',
    name: 'sunVillageInjointDetails',
    meta: {
      title: '财务公开', //财务公开
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/details'], resolve)
  },
  {
    path: '/sunVillage/injoint/meansOf',
    name: 'sunVillageInjointMeansOf',
    meta: {
      title: '三资公开', //清产核资
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/meansOf'], resolve)
  },
  {
    path: '/sunVillage/injoint/meansOf_desc',
    name: 'sunVillageInjointMeansOfDesc',
    meta: {
      title: '清产核资', //清产核资 --详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/meansOf_desc'], resolve)
  },
  {
    path: '/sunVillage/injoint/assetsPublic',
    name: 'sunVillageAssetsPublic',
    meta: {
      title: '三资公开', //资产公开
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/assetsPublic'], resolve)
  },
  {
    path: '/sunVillage/injoint/assetsPublic_desc',
    name: 'sunVillageAssetsPublicDesc',
    meta: {
      title: '资产公开', //资产公开
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/assetsPublic_desc'], resolve)
  },
  {
    path: '/sunVillage/injoint/publicResources',
    name: 'sunVillagePublicResources',
    meta: {
      title: '三资公开', //资源公开
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/publicResources'], resolve)
  },
  {
    path: '/sunVillage/injoint/publicResources_desc',
    name: 'sunVillagePublicResourcesDesc',
    meta: {
      title: '资源公开', //资源公开
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/dynamic/injoint/publicResources_desc'], resolve)
  },
  {
    path: '/sunVillage/consulting',
    name: 'sunVillageConsulting',
    meta: {
      title: '民生直通车', //民生直通车
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/consulting'], resolve)
  },
  {
    path: '/sunVillage/consulting/inquiries',
    name: 'sunVillageInquiries',
    meta: {
      title: '民生直通车', //民生直通车-咨询
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/inquiries'], resolve)
  },
  {
    path: '/sunVillage/consulting/my_consulting',
    name: 'sunVillageInquiries',
    meta: {
      title: '民生直通车', //民生直通车-我的咨询
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/my_consulting'], resolve)
  },
  {
    path: '/sunVillage/consulting/kanban',
    name: 'sunVillageKanban',
    meta: {
      title: '民生直通车', //民生直通车-民生看板
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/kanban/index'], resolve)
  },
  {
    path: '/sunVillage/consulting/kanban/focusList',
    name: 'sunVillageKanbanFocusList',
    meta: {
      title: '民生直通车', //民生直通车-民生看板-关注民生列表
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/kanban/focusList'], resolve)
  },
  {
    path: '/sunVillage/consulting/kanban/focusDesc',
    name: 'sunVillageKanbanFocusDesc',
    meta: {
      title: '民生直通车', //民生直通车-民生看板-关注民生详情
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/kanban/focusDesc'], resolve)
  },
  {
    path: '/sunVillage/consulting/kanban/affairsList',
    name: 'sunVillageKanbanAffairsList',
    meta: {
      title: '民生直通车', //民生直通车-民生看板-民生办事列表
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/throughTrain/kanban/affairsList'], resolve)
  },
  {
    path: '/sunVillage/equity',
    name: 'sunVillageEquity',
    meta: {
      title: '股权查询', //民生直通车-股民信息
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/equity/info'], resolve)
  },
  {
    path: '/sunVillage/equity_desc',
    name: 'sunVillageEquityDesc',
    meta: {
      title: '股权查询', //民生直通车-股民信息-详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/equity/info_desc'], resolve)
  },
  {
    path: '/sunVillage/shareBonus',
    name: 'sunVillageShareBonus',
    meta: {
      title: '股权查询', //民生直通车-股权分红
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/equity/shareBonus'], resolve)
  },
  {
    path: '/sunVillage/shareBonus_num',
    name: 'sunVillageShareBonusNum',
    meta: {
      title: '股权查询', //民生直通车-股权分红-详股数情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/equity/shareBonus_num'], resolve)
  },
  {
    path: '/sunVillage/shareBonus_amount',
    name: 'sunVillageShareBonusAmount',
    meta: {
      title: '股权查询', //民生直通车-股权分红-分红详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/equity/shareBonus_amount'], resolve)
  },
  {
    path: '/sunVillage/user/index',
    name: 'sunVillageUserIndex',
    meta: {
      title: '我的资料', //民生直通车-股权分红-分红详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/user/index'], resolve)
  },
  {
    path: '/sunVillage/user/mobile',
    name: 'sunVillageUserMobile',
    meta: {
      title: '修改手机号', //民生直通车-股权分红-分红详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/user/mobile'], resolve)
  },
  {
    path: '/sunVillage/user/information',
    name: 'sunVillageUserInformation',
    meta: {
      title: '修改用户信息', //民生直通车-股权分红-分红详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/user/information'], resolve)
  },
  {
    path: '/sunVillage/user/cooperative',
    name: 'sunVillageUserCooperative',
    meta: {
      title: '修改所属合作社', //民生直通车-股权分红-分红详情页
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage/user/cooperative'], resolve)
  },
  {
    path: '/zjdLogin',
    name: 'zjdLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/zjdLogin'], resolve)
  },
  {
    path: '/onlineHome/arbitrationList',
    name: 'arbitrationList',
    meta: {
      title: '纠纷调请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/arbitration/arbitrationList'], resolve)
  },
  {
    path: '/onlineHome/arbitrationDetail',
    name: 'arbitrationDetail',
    meta: {
      title: '纠纷调请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/arbitration/arbitrationDetail'], resolve)
  },
  {
    path: '/onlineHome/arbitrationProcessList',
    name: 'arbitrationProcessList',
    meta: {
      title: '纠纷处理',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/arbitration/arbitrationProcessList'], resolve)
  },
  {
    path: '/onlineHome/arbitrationProcessDetail',
    name: 'arbitrationProcessDetail',
    meta: {
      title: '纠纷处理过程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/arbitration/arbitrationProcessDetail'], resolve)
  },
  {
    path: '/onlineHome/arbitrationHandlerList',
    name: 'arbitrationHandlerList',
    meta: {
      title: '调解/仲裁员',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/arbitration/arbitrationHandlerList'], resolve)
  },
  {
    path: '/onlineHome/arbitrationHandlerDetail',
    name: 'arbitrationHandlerDetail',
    meta: {
      title: '纠纷处理员',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/arbitration/arbitrationHandlerDetail'], resolve)
  },
  {
    path: '/onlineHome/supervisionDetail',
    name: 'supervisionDetail',
    meta: {
      title: '宅基地监管详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionDetail'], resolve)
  },
  { //阳光村务（新）--登录页
    path: '/sunVillage_info/login',
    name: 'sunVillageInfoLogin',
    meta: {
      title: '报账员登录',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/login'], resolve)
  },
  { ////阳光村务（新）--主页
    path: '/sunVillage_info/index',
    name: 'sunVillageInfoIndex',
    meta: {
      title: '阳光村务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/index'], resolve)
  },
  { ////阳光村务（新）-- 二页-游客
    path: '/sunVillage_info/list_tourists',
    name: 'sunVillageInfoListTourists',
    meta: {
      title: '月度零工公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_tourists'], resolve)
  },
  { ////阳光村务（新）-- 固定资产
    path: '/sunVillage_info/fixedAssets',
    name: 'sunVillageInfoFixedAssets',
    meta: {
      title: '固定资产',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/fixedAssets'], resolve)
  },
  { ////阳光村务（新）-- 固定资产
    path: '/sunVillage_info/fixedAssetsAdd',
    name: 'sunVillageInfoFixedAssetsAdd',
    meta: {
      title: '新增固定资产',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/fixedAssetsAdd'], resolve)
  },
  { ////阳光村务（新）-- 固定资产
    path: '/sunVillage_info/fixedAssetsDetail',
    name: 'sunVillageInfoFixedAssetsDetail',
    meta: {
      title: '查看固定资产',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/fixedAssetsDetail'], resolve)
  },
  { ////阳光村务（新）-- 固定资产
    path: '/sunVillage_info/fixedAssetsEdit',
    name: 'sunVillageInfoFixedAssetsEdit',
    meta: {
      title: '修改固定资产',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/fixedAssetsEdit'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/information',
    name: 'sunVillageInfoInformation',
    meta: {
      title: '合同信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/information'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/informationAdd',
    name: 'sunVillageInfoInformationAdd',
    meta: {
      title: '新增合同信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/informationAdd'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/informationDetail',
    name: 'sunVillageInfoInformationDetail',
    meta: {
      title: '查看合同信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/informationDetail'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/informationEdit',
    name: 'sunVillageInfoInformationEdit',
    meta: {
      title: '修改合同信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/informationEdit'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/details',
    name: 'sunVillageInfoDetails',
    meta: {
      title: '详情页',
      hidden: true,
      keepAlive: true
    },
    component: (resolve) => require(['@/views/sunVillage_info/details'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/index_code',
    name: 'sunVillageInfoIndexCode',
    meta: {
      title: '阳光村务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/index_code'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_finance',
    name: 'sunVillageInfoListFinance',
    meta: {
      title: '财务公开榜',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_finance'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_issues',
    name: 'sunVillageInfoListIssues',
    meta: {
      title: '重大事项',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_issues'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_finance_add',
    name: 'sunVillageInfoListFinanceAdd',
    meta: {
      title: '新增财务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_finance_add'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_finance_detail',
    name: 'sunVillageInfoListFinanceDetail',
    meta: {
      title: '查看财务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_finance_detail'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_finance_ranking',
    name: 'sunVillageInfoListFinanceRanking',
    meta: {
      title: '收支情况公布榜',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_finance_ranking'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_tourists_add',
    name: 'sunVillageInfoListTouristsAdd',
    meta: {
      title: '新增零工公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_tourists_add'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_finance_edit',
    name: 'sunVillageInfoListFinanceEdit',
    meta: {
      title: '修改财务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_finance_edit'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_tourists_edit',
    name: 'sunVillageInfoListTouristsEdit',
    meta: {
      title: '修改零工公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_tourists_edit'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_tourists_detail',
    name: 'sunVillageInfoListTouristsDetail',
    meta: {
      title: '查看零工公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_tourists_detail'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_issues_add',
    name: 'sunVillageInfoListIssuesAdd',
    meta: {
      title: '新增重大事项',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_issues_add'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_issues_detail',
    name: 'sunVillageInfoListIssuesDetail',
    meta: {
      title: '查看重大事项',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_issues_detail'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_issues_edit',
    name: 'sunVillageInfoListIssuesEdit',
    meta: {
      title: '修改重大事项',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_issues_edit'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_tourists_ranking',
    name: 'sunVillageInfoListTouristsRanking',
    meta: {
      title: '零工公式公布榜',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_tourists_ranking'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_register',
    name: 'sunVillageInfoListRegister',
    meta: {
      title: '零工登记',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_register'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_register_add',
    name: 'sunVillageInfoListRegisterAdd',
    meta: {
      title: '新增零工登记',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_register_add'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_register_edit',
    name: 'sunVillageInfoListRegisterEdit',
    meta: {
      title: '新增零工登记',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_register_edit'], resolve)
  },
  { ////阳光村务（新）-- 合同信息
    path: '/sunVillage_info/list_register_detail',
    name: 'sunVillageInfoListRegisterDetail',
    meta: {
      title: '查看零工登记',
      hidden: true,
    },
    component: (resolve) => require(['@/views/sunVillage_info/list_register_detail'], resolve)
  }
];


export default new Router({
  linkActiveClass: 'active',
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
